OC.L10N.register(
    "core",
    {
    "File is too big" : "O ficheiro é grande de máis",
    "Invalid file provided" : "O ficheiro fornecido non é válido",
    "No image or file provided" : "Non forneceu ningunha imaxe ou ficheiro",
    "Unknown filetype" : "Tipo de ficheiro descoñecido",
    "Invalid image" : "Imaxe incorrecta",
    "No temporary profile picture available, try again" : "Non hai unha imaxe temporal de perfil dispoñíbel, volva tentalo",
    "No crop data provided" : "Non indicou como recortar",
    "No valid crop data provided" : "Os datos cortados fornecidos non son válidos",
    "Crop is not square" : "O corte non é cadrado",
    "Couldn't reset password because the token is invalid" : "No, foi posíbel restabelecer o contrasinal, a marca non é correcta",
    "%s password reset" : "Restabelecer o contrasinal %s",
    "Couldn't send reset email. Please contact your administrator." : "Non foi posíbel enviar o correo do restabelecemento. Póñase en contacto co administrador.",
    "Couldn't send mail to following users: %s " : "Non é posíbel enviar correo aos usuarios seguintes: %s",
    "Repair warning: " : "Aviso de arranxo:",
    "Repair error: " : "Arranxar o erro:",
    "Turned on maintenance mode" : "Modo de mantemento activado",
    "Turned off maintenance mode" : "Modo de mantemento desactivado",
    "Maintenance mode is kept active" : "Mantense activo o modo de mantemento",
    "Updated database" : "Base de datos actualizada",
    "Checked database schema update" : "Comprobada a actualización do esquema da base de datos",
    "Checked database schema update for apps" : "Comprobada a actualización do esquema da base de datos para aplicacións",
    "Updated \"%s\" to %s" : "Actualizado «%s» a %s",
    "Following apps have been disabled: %s" : "As seguintes aplicacións foron desactivadas: %s",
    "Sunday" : "domingo",
    "Monday" : "luns",
    "Tuesday" : "martes",
    "Wednesday" : "mércores",
    "Thursday" : "xoves",
    "Friday" : "venres",
    "Saturday" : "sábado",
    "Sun." : "dom.",
    "Mon." : "lun.",
    "Tue." : "mar.",
    "Wed." : "mér.",
    "Thu." : "xov.",
    "Fri." : "ven.",
    "Sat." : "sáb.",
    "Su" : "do",
    "Mo" : "lu",
    "Tu" : "ma",
    "We" : "mé",
    "Th" : "xo",
    "Fr" : "ve",
    "Sa" : "sá",
    "January" : "xaneiro",
    "February" : "febreiro",
    "March" : "marzo",
    "April" : "abril",
    "May" : "maio",
    "June" : "xuño",
    "July" : "xullo",
    "August" : "agosto",
    "September" : "setembro",
    "October" : "outubro",
    "November" : "novembro",
    "December" : "decembro",
    "Jan." : "xan.",
    "Feb." : "feb.",
    "Mar." : "mar.",
    "Apr." : "abr.",
    "May." : "mai.",
    "Jun." : "xuñ.",
    "Jul." : "xul.",
    "Aug." : "ago.",
    "Sep." : "set.",
    "Oct." : "out.",
    "Nov." : "nov.",
    "Dec." : "dec.",
    "Settings" : "Axustes",
    "Saving..." : "Gardando...",
    "Dismiss" : "Desbotar",
    "seconds ago" : "segundos atrás",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "A ligazón para restabelecer o seu contrasinal foi enviada ao seu correo. Se non a recibe nun prazo razoábel de tempo, vexa o seu cartafol de correo lixo. <br> Se non está ali pregúntelle ao administrador local.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Os seus ficheiros están cifrados. Se non activou a chave de recuperación, non haberá maneira de recuperar os datos após o restabelecemento do contrasinal. <br />Se non está seguro de que facer, póñase en contacto co administrador antes de continuar. <br /> Confirma que quere continuar?",
    "I know what I'm doing" : "Sei o estou a facer",
    "Password can not be changed. Please contact your administrator." : "Non é posíbel cambiar o contrasinal. Póñase en contacto co administrador.",
    "No" : "Non",
    "Yes" : "Si",
    "Choose" : "Escoller",
    "Error loading file picker template: {error}" : "Produciuse un erro ao cargar o modelo do selector: {error}",
    "Ok" : "Aceptar",
    "Error loading message template: {error}" : "Produciuse un erro ao cargar o modelo da mensaxe: {error}",
    "read-only" : "só lectura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflito de ficheiro","{count} conflitos de ficheiros"],
    "One file conflict" : "Un conflito de ficheiro",
    "New Files" : "Ficheiros novos",
    "Already existing files" : "Ficheiros xa existentes",
    "Which files do you want to keep?" : "Que ficheiros quere conservar?",
    "If you select both versions, the copied file will have a number added to its name." : "Se selecciona ambas versións, o ficheiro copiado terá un número engadido ao nome.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todo o seleccionado)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Produciuse un erro ao cargar o modelo de ficheiro existente",
    "Very weak password" : "Contrasinal moi feble",
    "Weak password" : "Contrasinal feble",
    "So-so password" : "Contrasinal non moi aló",
    "Good password" : "Bo contrasinal",
    "Strong password" : "Contrasinal forte",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "O servidor aínda non está configurado correctamente para permitir a sincronización de ficheiros, semella que a interface WebDAV non está a funcionar.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Este servidor non ten conexión activa a Internet. Isto significa que algunhas características como a montaxe do almacenamento externo, as notificacións sobre actualizacións ou a instalación de engadidos de terceiros non funcionarán. Así mesmo,  o acceso remoto a ficheiros e enviar correos de notificación poderían non funcionar. Suxerímoslle que active a conexión a Internet para este servidor se quere ter todos estes servizos.",
    "Error occurred while checking server setup" : "Aconteceu un erro mentras se comprobaba a configuración do servidor",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "O directorio de datos e os seus ficheiros probabelmente son accesíbeis desde a Internet. O ficheiro .htaccess non funciona. Recomendámoslle que configure o seu servidor web de xeito que o directorio de datos non sexa accesíbel ou que mova o directorio de datos fora do directorio root do servidor web.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "A cabeceira HTTP «{header}» non está configurada como igual a «{expected}». Isto é un posíbel risco para a seguridade ou a intimidade, recomendámoslle que axuste esta opción.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Está accedendo a este sitio a través de HTTP. Suxerímoslle que configure o seu servidor para requirir, no seu canto, o uso de HTTPS, tal e como se descrine nos<a href=\"{docUrl}\">consellos de seguridade</a>.",
    "Shared" : "Compartido",
    "Shared with {recipients}" : "Compartido con {recipients}",
    "Error" : "Erro",
    "Error while sharing" : "Produciuse un erro ao compartir",
    "Error while unsharing" : "Produciuse un erro ao deixar de compartir",
    "The public link will expire no later than {days} days after it is created" : "A ligazón pública caducará, a máis tardar, {days} días após a súa creación",
    "Set expiration date" : "Definir a data de caducidade",
    "Expiration" : "Caducidade",
    "Expiration date" : "Data de caducidade",
    "Link" : "Ligazón",
    "Edit" : "Editar",
    "Remove" : "Retirar",
    "Choose a password for the public link" : "Escolla un contrasinal para a ligazón pública",
    "Filename" : "Nome de ficheiro",
    "Password" : "Contrasinal",
    "Name" : "Nome",
    "Allow editing" : "Permitir a edición",
    "Save" : "Gardar",
    "Sending ..." : "Enviando...",
    "Email sent" : "Correo enviado",
    "Email link to person" : "Enviar ligazón por correo",
    "Shared with you and the group {group} by {owner}" : "Compartido con vostede e co grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido con vostede por {owner}",
    "group" : "grupo",
    "remote" : "remoto",
    "notify by email" : "notificar por correo",
    "Unshare" : "Deixar de compartir",
    "can share" : "pode compartir",
    "can edit" : "pode editar",
    "create" : "crear",
    "change" : "cambio",
    "delete" : "eliminar",
    "access control" : "control de acceso",
    "Share" : "Compartir",
    "Resharing is not allowed" : "Non se permite volver compartir",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Comparta con outra xente ou con outros ownClouds empregando a sintaxe «nomeusuario@exemplo.com/ouwncloud»",
    "Warning" : "Aviso",
    "Delete" : "Eliminar",
    "Rename" : "Renomear",
    "The object type is not specified." : "Non se especificou o tipo de obxecto.",
    "Enter new" : "Introduza o novo",
    "Add" : "Engadir",
    "Edit tags" : "Editar etiquetas",
    "Error loading dialog template: {error}" : "Produciuse un erro ao cargar o modelo do dialogo: {error}",
    "No tags selected for deletion." : "Non se seleccionaron etiquetas para borrado.",
    "unknown text" : "texto descoñecido",
    "Hello world!" : "Ola xente!",
    "sunny" : "soleado",
    "Hello {name}, the weather is {weather}" : "Ola {name}, o tempo é {weather}",
    "Hello {name}" : "Ola {name}",
    "_download %n file_::_download %n files_" : ["descargar %n ficheiro","descargar %n ficheiros"],
    "Please reload the page." : "Volva cargar a páxina.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "A actualización non foi satisfactoria, informe deste problema á  <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">comunidade de ownCloud</a>.",
    "The update was successful. There were warnings." : "A actualización realizouse correctamente. Houbo algún aviso.",
    "The update was successful. Redirecting you to ownCloud now." : "A actualización realizouse correctamente. Redirixíndoo agora á ownCloud.",
    "Searching other places" : "Buscando noutros lugares",
    "Personal" : "Persoal",
    "Users" : "Usuarios",
    "Apps" : "Aplicacións",
    "Admin" : "Administración",
    "Help" : "Axuda",
    "Access forbidden" : "Acceso denegado",
    "File not found" : "Ficheiro non atopado",
    "The specified document has not been found on the server." : "Non se atopou no servidor o documento indicado.",
    "You can click here to return to %s." : "Pode premer aquí para volver a %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Ola,\n\nsó facerlle saber que %s compartiu %s con vostede.\nVéxao en: %s\n\n",
    "The share will expire on %s." : "Esta compartición caduca o %s.",
    "Cheers!" : "Saúdos!",
    "Internal Server Error" : "Produciuse un erro interno do servidor",
    "The server encountered an internal error and was unable to complete your request." : "O servidor atopou un erro interno e non foi quen de completar a súa petición.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Contacte co administrador se este erro acontece repetidamente, favor inclúa os detalles técnicos indicados embaixo no seu informe.",
    "More details can be found in the server log." : "Atopará máis detalles no rexistro do servidor.",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Enderezo remoto: %s",
    "Request ID: %s" : "ID da petición: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensaxe: %s",
    "File: %s" : "Ficheiro: %s",
    "Line: %s" : "Liña: %s",
    "Trace" : "Traza",
    "Create an <strong>admin account</strong>" : "Crear unha <strong>contra de administrador</strong>",
    "Username" : "Nome de usuario",
    "Storage & database" : "Almacenamento e base de datos",
    "Data folder" : "Cartafol de datos",
    "Configure the database" : "Configurar a base de datos",
    "Only %s is available." : "Só está dispoñíbel %s.",
    "Install and activate additional PHP modules to choose other database types." : "Instale e active os módulos de PHP adicionais para seleccionar outros tipos de bases de datos.",
    "For more details check out the documentation." : "Para obter máis detalles revise a documentación.",
    "Database user" : "Usuario da base de datos",
    "Database password" : "Contrasinal da base de datos",
    "Database name" : "Nome da base de datos",
    "Database tablespace" : "Táboa de espazos da base de datos",
    "Database host" : "Servidor da base de datos",
    "Performance warning" : "Aviso de rendemento",
    "SQLite will be used as database." : "Utilizarase SQLite como base de datos",
    "For larger installations we recommend to choose a different database backend." : "Para instalacións grandes, recomendámoslle que empregue unha infraestrutura de base de datos diferente.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Concretamente, se emprega o cliente de escritorio para sincronización, desaconséllase o uso de SQLite.",
    "Finish setup" : "Rematar a configuración",
    "Finishing …" : "Rematando ...",
    "Need help?" : "Precisa axuda?",
    "See the documentation" : "Vexa a documentación",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Ola,<br><br>só facerlle saber que %s compartiu <strong>%s</strong> con vostede.<br><a href=\"%s\">Véxao!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación require JavaScript para un correcto funcionamento. {linkstart}Active  JavaScript{linkend} e volva cargar a páxina.",
    "Log out" : "Desconectar",
    "Search" : "Buscar",
    "Server side authentication failed!" : "A autenticación fracasou do lado do servidor!",
    "Please contact your administrator." : "Contacte co administrador.",
    "Please try again or contact your administrator." : "Ténteo de novo ou póñase en contacto co administrador.",
    "Log in" : "Acceder",
    "Alternative Logins" : "Accesos alternativos",
    "Use the following link to reset your password: {link}" : "Usa a seguinte ligazón para restabelecer o contrasinal: {link}",
    "New password" : "Novo contrasinal",
    "New Password" : "Novo contrasinal",
    "Reset password" : "Restabelecer o contrasinal",
    "This ownCloud instance is currently in single user mode." : "Esta instancia do ownCloud está actualmente en modo de usuario único.",
    "This means only administrators can use the instance." : "Isto significa que só os administradores poden utilizar a instancia.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Póñase en contacto co administrador do sistema se persiste esta mensaxe ou se aparece de forma inesperada.",
    "Thank you for your patience." : "Grazas pola súa paciencia.",
    "You are accessing the server from an untrusted domain." : "Esta accedendo desde un dominio non fiábel.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Dependendo da súa configuración, como administrador vostede podería utilizar o botón de embaixo para confiar neste dominio.",
    "Add \"%s\" as trusted domain" : "Engadir «%s» como dominio de confianza",
    "App update required" : "É necesario actualizar a aplicación",
    "%s will be updated to version %s" : "%s actualizarase á versión %s",
    "These apps will be updated:" : "Actualizaranse estas aplicacións:",
    "The theme %s has been disabled." : "O tema %s foi desactivado.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asegúrese de ter feito unha copia de seguranza da base de datos, do cartafol de configuración e do cartafol de datos, antes de proceder.",
    "Start update" : "Iniciar a actualización",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos de espera nas instalacións grandes, no seu lugar pode executar a seguinte orde desde o directorio de instalación:",
    "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia de %s atopase en modo de mantemento, isto pode levar un anaco.",
    "This page will refresh itself when the %s instance is available again." : "Esta páxina actualizarase automaticamente cando a instancia de %s estea dispoñíbel de novo.",
    "Copy to clipboard" : "Copiar ao portapapeis",
    "Menu" : "Menú"
},
"nplurals=2; plural=(n != 1);");
